
# This file was generated by 'versioneer.py' (0.18) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2021-01-05T17:43:31-0800",
 "dirty": false,
 "error": null,
 "full-revisionid": "3aa604df8766d698716016c428ee53cb4b9beac0",
 "version": "0.25.31"
}
'''  # END VERSION_JSON


def get_versions():
    return json.loads(version_json)
